# Cooperator Worker Configuration

- Configure on share product whether its owner can work and shop
- Partner fields is_worker and can_shop are computed from the share they subscribed to.

Table of contents

- Bug Tracker
- Credits
  - Authors
  - Contributors
  - Maintainers

# Bug Tracker

Bugs are tracked on GitHub Issues. In case of trouble, please check there if your issue has already been reported. If you spotted it first, help us to smash it by providing a detailed and welcomed feedback.

Do not contact contributors directly about support or help with technical issues.

# Credits

## Authors

- BEES coop
- Coop IT Easy SC

## Contributors

- BEES coop
- Coop IT Easy SC

## Maintainers

This module is part of the beescoop/Obeesdoo project on GitHub.

You are welcome to contribute.